import unittest

from tracklr import Tracklr


class TestTracklr(unittest.TestCase):

    def setUp(self):

        self.tracklr = Tracklr()

    def test_tracklr_init(self):

        self.assertIn("bdtrpfi80dtav668iqd38oqi7g", self.tracklr.__config__)

    def test_tracklr_report(self):

        report = self.tracklr.get_report(None, None, None, None, None)

    def test_tracklr_banner(self):

        banner = self.tracklr.banner(None, use_figlet=False)

        self.assertIn("Tracklr v", banner)



from os.path import expanduser
import unittest

from tracklr.vdir import Vdir


class TestVdir(unittest.TestCase):

    def test_vdir(self):

        vdir = Vdir(
            expanduser("tests/vdir_storage")
        )

        vdir_list = vdir.list()

        events = []

        for event in vdir_list:
            events.append(event)
            self.assertEqual(event, "3e6c9ccb-a33f-4224-98d6-018704b761e1.ics")

        self.assertEqual(len(events), 1)

        event_data = vdir.get(event)
        self.assertIn("@Tracklr +test #Vdir storage", event_data)

    def test_vdir_does_not_exist(self):

        with self.assertRaises(IOError):
             vdir = Vdir("")



import unittest

from tracklr.main import TracklrApp
from tracklr.info import Info


class TestPDFCommand(unittest.TestCase):

    def test_info(self):
        app = TracklrApp()
        info = Info(app, None)



import unittest

from tracklr.main import TracklrApp
from tracklr.group import Group


class TestPDFCommand(unittest.TestCase):

    def test_group(self):
        app = TracklrApp()
        group = Group(app, None)
